Reference Manual
================

Modules in Acoular
------------------
The following modules are part of Acoular:

.. currentmodule:: acoular 

.. autosummary::
    :toctree: generated/

    calib
    configuration
    environments
    fbeamform
    grids
    microphones
    sdinput
    signals
    sources
    spectra
    tbeamform
    tools
    tprocess
    trajectory




Classes in Acoular and their inheritance
----------------------------------------
**Depending on the resolution of your browser window the cross links may not be positioned correctly!**


.. inheritance-diagram:: acoular.environments acoular.calib acoular.configuration
                acoular.fbeamform acoular.grids acoular.microphones acoular.sdinput 
                acoular.signals acoular.sources acoular.spectra acoular.tbeamform
                acoular.tools acoular.tprocess acoular.trajectory
    :top-classes: acoular.environments.Environment, 
                acoular.environments.FlowField,
                acoular.calib.Calib,
                acoular.configuration.Config,
                acoular.fbeamform.BeamformerBase,
                acoular.fbeamform.SteeringVector,
                acoular.fbeamform.PointSpreadFunction,
                acoular.grids.Grid, 
                acoular.grids.Sector,
                acoular.microphones.MicGeom,
                acoular.signals.SignalGenerator,
                acoular.tprocess.SamplesGenerator,           
                acoular.spectra.BaseSpectra,
                acoular.trajectory.Trajectory
    :parts: 1

:mod:`acoular` Package
----------------------

.. automodule:: acoular.__init__
    :members:
    :undoc-members:
    :show-inheritance:

